yakumo.cinder.v2.consistency_group

Package yakumo :: Package cinder :: Package v2 :: Module consistency_group |
[hide private]
[frames] | no frames]

# Module consistency_group

source code

Resource class and its manager for consistency group on Block Storage V2 API

Classes | [hide private]
| Resource resource class for consistency group on Block Storage V2 API
| Manager manager class for consistency group on Block Storage V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'display_description', mapper.Noop), ('volume_types', 'volume__ty
      pes', mapper.List(mapper.Resource('cinder.volume_type'))), ('availabil
      ity_zone', 'availability_zone', mapper.Resource('availability_zone')),
       ('status', 'status', mapper.Noop), ('created_at', 'created_at', mappe
      r.DateTime),]